==> nuxt__opencollective-0.2.1.jar: META-INF/resources/webjars/nuxt__opencollective/0.2.1/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

<a name="0.2.1"></a>
## [0.2.1](https://github.com/nuxt-community/opencollective/compare/v0.2.0...v0.2.1) (2018-12-12)


### Bug Fixes

* **bin:** force exit process ([#4](https://github.com/nuxt-community/opencollective/issues/4)) ([b5b0a81](https://github.com/nuxt-community/opencollective/commit/b5b0a81))
* gracefully handle network errors ([#3](https://github.com/nuxt-community/opencollective/issues/3)) ([04df30a](https://github.com/nuxt-community/opencollective/commit/04df30a))



<a name="0.2.0"></a>
# [0.2.0](https://github.com/nuxt-community/opencollective/compare/v0.1.0...v0.2.0) (2018-11-25)


### Bug Fixes

* **ci:** add build step ([d8e7314](https://github.com/nuxt-community/opencollective/commit/d8e7314))


### Features

* update consola and esm dependencies ([714ca65](https://github.com/nuxt-community/opencollective/commit/714ca65))


### Performance Improvements

* **pkg:** use CJS dist for smaller package and faster startup ([2ade457](https://github.com/nuxt-community/opencollective/commit/2ade457))



<a name="0.1.0"></a>
# 0.1.0 (2018-09-02)


### Bug Fixes

* legacy logo query ([c1b5b91](https://github.com/nuxt-community/opencollective/commit/c1b5b91))
* print donation text and url ([1d54f60](https://github.com/nuxt-community/opencollective/commit/1d54f60))


### Features

* make it work ([8d1cb6e](https://github.com/nuxt-community/opencollective/commit/8d1cb6e))

==> nuxt__opencollective-0.2.2.jar: META-INF/resources/webjars/nuxt__opencollective/0.2.2/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

<a name="0.2.2"></a>
## [0.2.2](https://github.com/nuxt-community/opencollective/compare/v0.2.1...v0.2.2) (2019-04-02)


### Bug Fixes

* properly hide message ([#6](https://github.com/nuxt-community/opencollective/issues/6)) ([ed2efb0](https://github.com/nuxt-community/opencollective/commit/ed2efb0))



<a name="0.2.1"></a>
## [0.2.1](https://github.com/nuxt-community/opencollective/compare/v0.2.0...v0.2.1) (2018-12-12)


### Bug Fixes

* **bin:** force exit process ([#4](https://github.com/nuxt-community/opencollective/issues/4)) ([b5b0a81](https://github.com/nuxt-community/opencollective/commit/b5b0a81))
* gracefully handle network errors ([#3](https://github.com/nuxt-community/opencollective/issues/3)) ([04df30a](https://github.com/nuxt-community/opencollective/commit/04df30a))



<a name="0.2.0"></a>
# [0.2.0](https://github.com/nuxt-community/opencollective/compare/v0.1.0...v0.2.0) (2018-11-25)


### Bug Fixes

* **ci:** add build step ([d8e7314](https://github.com/nuxt-community/opencollective/commit/d8e7314))


### Features

* update consola and esm dependencies ([714ca65](https://github.com/nuxt-community/opencollective/commit/714ca65))


### Performance Improvements

* **pkg:** use CJS dist for smaller package and faster startup ([2ade457](https://github.com/nuxt-community/opencollective/commit/2ade457))



<a name="0.1.0"></a>
# 0.1.0 (2018-09-02)


### Bug Fixes

* legacy logo query ([c1b5b91](https://github.com/nuxt-community/opencollective/commit/c1b5b91))
* print donation text and url ([1d54f60](https://github.com/nuxt-community/opencollective/commit/1d54f60))


### Features

* make it work ([8d1cb6e](https://github.com/nuxt-community/opencollective/commit/8d1cb6e))
